@@ -51,6 +51,7 @@
 #include <libgames-support/games-clock.h>
 #include <libgames-support/games-files.h>
 #include <libgames-support/games-stock.h>
+#include <libgames-support/games-sound.h>
 
 #include "board.h"
 #include "conf.h"
@@ -87,6 +88,7 @@ enum
   ACTION_FULLSCREEN,
   ACTION_HELP_GAME,
   ACTION_OPTIONS_MENU,
+  ACTION_DEAL,
   ACTION_HINT,
 #ifdef HAVE_MAEMO
   ACTION_ACCEL_UNDO_MOVE,
@@ -402,8 +404,11 @@ show_game_over_dialog (AisleriotWindow *window)
 
   if (game_won) {
     message = _("Congratulations, you have won!");
+    games_sound_play ("victory");
+
   } else {
     message =  _("There are no more moves");
+    games_sound_play ("splat");
   }
 
   dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (window),
@@ -548,6 +553,7 @@ help_about_cb (GtkAction *action,
     "Rosanna Yuen <zana@webwynk.net>",
     "Callum McKenzie <callum@physics.otago.ac.nz>",
     "Christian Persch <chpe" "\100" "gnome.org>",
+    "Andreas Røsdal <andreasr" "\100" "gnome.org>",
     "",
     _("Card games:"),
     "Jonathan Blandford <jrb@redhat.com>",
@@ -557,6 +563,8 @@ help_about_cb (GtkAction *action,
     "Changwoo Ryu <cwryu@adam.kaist.ac.kr>",
     "Matthew Wilcox <matthew@wil.cx>",
     "Rosanna Yuen <zana@webwynk.net>",
+    "Alan Horkan <horkana@maths.tcd.ie>",
+    "Richard Hoelscher <rah@rahga.com>",
     NULL
   };
   const char *artists[] = {
@@ -909,6 +917,20 @@ clickmove_toggle_cb (GtkToggleAction *action,
   games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_CLICK_TO_MOVE), click_to_move);
 }
 
+static void
+sound_toggle_cb (GtkToggleAction *action,
+                 AisleriotWindow *window)
+{
+  AisleriotWindowPrivate *priv = window->priv;
+  gboolean sound_enabled;
+
+  sound_enabled = gtk_toggle_action_get_active (action);
+
+  games_sound_enable (sound_enabled);
+  
+  games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_SOUND), sound_enabled);
+}
+
 static void
 show_hint_cb (GtkAction *action,
               AisleriotWindow *window)
@@ -1061,6 +1083,15 @@ show_hint_cb (GtkAction *action,
   g_free (message);
 }
 
+static void
+deal_cb (GtkAction *action,
+         AisleriotWindow *window)
+{
+  AisleriotWindowPrivate *priv = window->priv;
+
+  aisleriot_game_deal_cards (priv->game);
+}
+
 /* Make something that's easier to store in conf */
 static guint
 compress_options_to_int (SCM options_list)
@@ -1620,14 +1651,28 @@ sync_game_redoable (AisleriotGame *game,
   gtk_action_set_sensitive (priv->action[ACTION_REDO_MOVE], enabled);
 }
 
+static void
+sync_game_dealable (AisleriotGame *game,
+                    GParamSpec *pspec,
+                    AisleriotWindow *window)
+{
+  AisleriotWindowPrivate *priv = window->priv;
+  gboolean enabled;
+
+  g_object_get (game, "can-deal", &enabled, NULL);
+
+  gtk_action_set_sensitive (priv->action[ACTION_DEAL], enabled);
+}
+
 static void
 game_type_changed_cb (AisleriotGame *game,
                       AisleriotWindow *window)
 {
   AisleriotWindowPrivate *priv = window->priv;
   char *game_name;
-#ifndef HAVE_MAEMO
   guint features;
+  gboolean dealable;
+#ifndef HAVE_MAEMO
   gboolean show_scores;
 #endif /* !HAVE_MAEMO */
 
@@ -1650,6 +1695,11 @@ game_type_changed_cb (AisleriotGame *game,
 
   update_statistics_display (window);
 
+  features = aisleriot_game_get_features (game);
+
+  dealable = (features & FEATURE_DEALABLE) != 0;
+  gtk_action_set_visible (priv->action[ACTION_DEAL], dealable);
+
 #ifdef HAVE_MAEMO
   gtk_label_set_text (priv->game_message_label, NULL);
 #else
@@ -1657,8 +1707,6 @@ game_type_changed_cb (AisleriotGame *game,
 
   gtk_statusbar_pop (priv->statusbar, priv->game_message_id);
 
-  features = aisleriot_game_get_features (game);
-
   show_scores = (features & FEATURE_SCORE_HIDDEN) == 0;
   g_object_set (priv->score_box, "visible", show_scores, NULL);
 #endif
@@ -1913,6 +1961,9 @@ aisleriot_window_init (AisleriotWindow *window)
       G_CALLBACK (undo_cb) },
     { "RedoMove", GAMES_STOCK_REDO_MOVE, NULL, NULL, NULL,
       G_CALLBACK (redo_cb) },
+    { "Deal", GTK_STOCK_OK /* FIXMEchpe */, _("_Deal"), "<control>D",
+      ACTION_TOOLTIP (N_("Deal next card or cards")),
+      G_CALLBACK (deal_cb) },
     { "Hint", GAMES_STOCK_HINT, NULL, NULL, NULL,
       G_CALLBACK (show_hint_cb) },
     { "Contents", GAMES_STOCK_CONTENTS, NULL, NULL,
@@ -1969,6 +2020,10 @@ aisleriot_window_init (AisleriotWindow *window)
       ACTION_TOOLTIP (N_("Pick up and drop cards by clicking")),
       G_CALLBACK (clickmove_toggle_cb),
       FALSE /* not active by default */ },
+   { "Sound", NULL, N_("_Enable sounds"), NULL,
+      ACTION_TOOLTIP (N_("Whether or not to play event sounds.")),
+      G_CALLBACK (sound_toggle_cb),
+      FALSE /* not active by default */ },
 #ifdef ENABLE_DEBUG_UI
     { "DebugPixbufDrawing", NULL, "_Pixbuf drawing", NULL, NULL,
       G_CALLBACK (debug_pixbuf_drawing_cb),
@@ -1983,6 +2038,7 @@ aisleriot_window_init (AisleriotWindow *window)
     "Fullscreen",
     "HelpGame",
     "OptionsMenu",
+    "Deal",
     "Hint",
 #ifdef HAVE_MAEMO
     "AccelUndoMove",
@@ -2014,6 +2070,7 @@ aisleriot_window_init (AisleriotWindow *window)
         "<menu action='ControlMenu'>"
           "<menuitem action='UndoMove'/>"
           "<menuitem action='RedoMove'/>"
+          "<menuitem action='Deal'/>"
           "<menuitem action='Hint'/>"
           "<separator/>"
           "<menuitem action='ClickToMove'/>"
@@ -2053,9 +2110,11 @@ aisleriot_window_init (AisleriotWindow *window)
         "<menu action='ControlMenu'>"
           "<menuitem action='UndoMove'/>"
           "<menuitem action='RedoMove'/>"
+          "<menuitem action='Deal'/>"
           "<menuitem action='Hint'/>"
           "<separator/>"
           "<menuitem action='ClickToMove'/>"
+          "<menuitem action='Sound'/>"
         "</menu>"
         "<menu action='OptionsMenu'/>"
         "<menu action='HelpMenu'>"
@@ -2083,6 +2142,7 @@ aisleriot_window_init (AisleriotWindow *window)
         "<separator/>"
         "<toolitem action='UndoMove'/>"
         "<toolitem action='RedoMove'/>"
+        "<toolitem action='Deal'/>"
         "<toolitem action='Hint'/>"
 #ifndef HAVE_MAEMO
         "<toolitem action='LeaveFullscreen'/>"
@@ -2178,6 +2238,9 @@ aisleriot_window_init (AisleriotWindow *window)
     g_assert (priv->action[i]);
   }
 
+  /* Hide the "Deal" action initially, since not all games support it */
+  gtk_action_set_visible (priv->action[ACTION_DEAL], FALSE);
+
 #ifndef HAVE_MAEMO
   statusbar = priv->statusbar = GTK_STATUSBAR (gtk_statusbar_new ());
   priv->game_message_id = gtk_statusbar_get_context_id (priv->statusbar, "game-message");
@@ -2261,6 +2324,10 @@ aisleriot_window_init (AisleriotWindow *window)
   action = gtk_action_group_get_action (priv->action_group, "ClickToMove");
   gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
                                 games_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_CLICK_TO_MOVE), NULL));
+  action = gtk_action_group_get_action (priv->action_group, "Sound");
+  gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
+                                games_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_SOUND), NULL));
+  gtk_action_set_visible (action, games_sound_is_available ());
   action = gtk_action_group_get_action (priv->action_group, "RecentMenu");
   g_object_set (action, "hide-if-empty", FALSE, NULL);
 
@@ -2300,6 +2367,9 @@ aisleriot_window_init (AisleriotWindow *window)
   sync_game_redoable (priv->game, NULL, window);
   g_signal_connect (priv->game, "notify::can-redo",
                     G_CALLBACK (sync_game_redoable), window);
+  sync_game_dealable (priv->game, NULL, window);
+  g_signal_connect (priv->game, "notify::can-deal",
+                    G_CALLBACK (sync_game_dealable), window);
 
   g_signal_connect (priv->game, "game-type",
                     G_CALLBACK (game_type_changed_cb), window);
@@ -2314,7 +2384,7 @@ aisleriot_window_init (AisleriotWindow *window)
   gtk_window_set_default_size (GTK_WINDOW (window), MIN_WIDTH, MIN_HEIGHT);
 
   /* Restore window state */
-  games_conf_add_window (GTK_WINDOW (window));
+  games_conf_add_window (GTK_WINDOW (window), NULL);
 
   /* Initial focus is in the board */
   gtk_widget_grab_focus (GTK_WIDGET (priv->board));
@@ -2466,21 +2536,22 @@ load_idle_cb (LoadIdleData *data)
                                      name);
     g_free (name);
 
-    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-                                              "%s", error->message);
-    g_error_free (error);
-
     if (priv->freecell_mode ||
-        (error->domain == g_quark_from_static_string ("AisleRiot") &&
-         error->code == GAME_ERROR_FALLBACK)) {
-      /* Loading the fallback game failed; all we can do is exit */
+        error->domain != AISLERIOT_GAME_ERROR ||
+        error->code != GAME_ERROR_FALLBACK) {
+      /* Loading freecell/the fallback game failed; all we can do is exit */
       g_signal_connect_swapped (dialog, "response",
                                 G_CALLBACK (gtk_widget_destroy), data->window);
     } else {
+      gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+                                                "%s", error->message);
+
       g_signal_connect (dialog, "response",
                         G_CALLBACK (load_error_response_cb), data->window);
     }
 
+    g_error_free (error);
+
     gtk_window_present (GTK_WINDOW (dialog));
 
     return FALSE;
