@@ -24,11 +24,12 @@
 #include <string.h>
 #include <gdk/gdkkeysyms.h>
 #include <time.h>
-#include <gconf/gconf-client.h>
 
 #include <games-gridframe.h>
 #include <games-stock.h>
 #include <games-scores.h>
+#include <games-sound.h>
+#include <games-conf.h>
 
 #include "main.h"
 #include "properties.h"
@@ -47,6 +48,8 @@
 #include <ggz-embed.h>
 #endif
 
+#define DEFAULT_WIDTH 650
+#define DEFAULT_HEIGHT 520
 
 GtkWidget *window;
 GtkWidget *drawing_area;
@@ -228,7 +231,7 @@ delete_cb (GtkWidget * widget, gpointer data)
 static void
 quit_cb (GObject * object, gpointer data)
 {
-  gtk_main_quit ();
+  gtk_widget_destroy (window);
 }
 
 static void
@@ -240,7 +243,11 @@ about_cb (GtkAction * action, gpointer data)
   gchar *license = games_get_license (_("Nibbles"));
 
   gtk_show_about_dialog (GTK_WINDOW (window),
+#if GTK_CHECK_VERSION (2, 11, 0)
+                         "program-name", _("Nibbles"),
+#else
 			 "name", _("Nibbles"),
+#endif
 			 "version", VERSION,
 			 "copyright",
 			 "Copyright \xc2\xa9 1999-2007 Sean MacIsaac, Ian Peters, Andreas Røsdal",
@@ -248,7 +255,7 @@ about_cb (GtkAction * action, gpointer data)
 			 _("A worm game for GNOME."), "authors", authors,
 			 "documenters", documenters, "translator-credits",
 			 _("translator-credits"), "logo-icon-name",
-			 "gnome-nibbles", "website",
+			 "gnome-gnibbles", "website",
 			 "http://www.gnome.org/projects/gnome-games/",
 			 "wrap-license", TRUE, NULL);
   g_free (license);
@@ -309,14 +316,6 @@ draw_board ()
 
 }
 
-static gboolean
-window_configure_event_cb (GtkWidget * widget, GdkEventConfigure * event)
-{
-  gnibbles_properties_set_height (event->height);
-  gnibbles_properties_set_width (event->width);
-  return FALSE;
-}
-
 static gboolean
 configure_event_cb (GtkWidget * widget, GdkEventConfigure * event)
 {
@@ -366,7 +365,7 @@ configure_event_cb (GtkWidget * widget, GdkEventConfigure * event)
   else
     render_logo ();
 
-  return (FALSE);
+  return FALSE;
 }
 
 #ifdef GGZ_CLIENT
@@ -878,15 +877,18 @@ setup_window (void)
   GtkAccelGroup *accel_group;
 
   window = gnome_app_new ("gnibbles", "Nibbles");
-  gtk_widget_realize (window);
-  gtk_window_resize (GTK_WINDOW (window), properties->width,
-		     properties->height);
-  g_signal_connect (G_OBJECT (window), "destroy", G_CALLBACK (quit_cb), NULL);
+
+  gtk_window_set_default_size (GTK_WINDOW (window), DEFAULT_WIDTH, DEFAULT_HEIGHT);
+  games_conf_add_window (GTK_WINDOW (window), KEY_PREFERENCES_GROUP);
+
+  g_signal_connect (G_OBJECT (window), "destroy", G_CALLBACK (gtk_main_quit), NULL);
   g_signal_connect (G_OBJECT (window), "delete_event",
 		    G_CALLBACK (delete_cb), NULL);
   g_signal_connect (G_OBJECT (window), "window_state_event",
 		    G_CALLBACK (window_state_cb), NULL);
 
+  gtk_widget_realize (window);
+
   vbox = gtk_vbox_new (FALSE, 0);
 
   games_stock_init ();
@@ -929,9 +931,6 @@ setup_window (void)
   g_signal_connect (G_OBJECT (drawing_area), "configure_event",
 		    G_CALLBACK (configure_event_cb), NULL);
 
-  g_signal_connect (G_OBJECT (window), "configure_event",
-		    G_CALLBACK (window_configure_event_cb), NULL);
-
   g_signal_connect (G_OBJECT (drawing_area), "motion_notify_event",
 		    G_CALLBACK (show_cursor_cb), NULL);
 
@@ -964,30 +963,6 @@ setup_window (void)
 
 }
 
-static void
-gconf_key_change_cb (GConfClient * client, guint cnxn_id,
-		     GConfEntry * entry, gpointer user_data)
-{
-  gnibbles_properties_update (properties);
-}
-
-static void
-load_properties ()
-{
-  GConfClient *client;
-
-  properties = gnibbles_properties_new ();
-  client = gconf_client_get_default ();
-
-  /* maybe this should to into properties.c */
-  gconf_client_add_dir (client,
-			KEY_DIR, GCONF_CLIENT_PRELOAD_RECURSIVE, NULL);
-  gconf_client_notify_add (client,
-			   KEY_PREFERENCES_DIR,
-			   gconf_key_change_cb, NULL, NULL, NULL);
-}
-
-
 static void
 render_logo (void)
 {
@@ -1053,6 +1028,7 @@ int
 main (int argc, char **argv)
 {
   GnomeProgram *program;
+  GOptionContext *context;
 
   setgid_io_init ();
 
@@ -1060,16 +1036,23 @@ main (int argc, char **argv)
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
+  g_thread_init (NULL);
+  context = g_option_context_new (NULL);
+  games_sound_add_option_group (context);
+
   program = gnome_program_init ("gnibbles", VERSION, LIBGNOMEUI_MODULE,
 				argc, argv,
+				GNOME_PARAM_GOPTION_CONTEXT, context,
 				GNOME_PARAM_POPT_TABLE, NULL,
 				GNOME_PARAM_APP_DATADIR, REAL_DATADIR, NULL);
-  gtk_window_set_default_icon_name ("gnome-nibbles");
+  gtk_window_set_default_icon_name ("gnome-gnibbles");
   srand (time (NULL));
 
   highscores = games_scores_new (&scoredesc);
 
-  load_properties ();
+  games_conf_initialise ("Gnibbles");
+
+  properties = gnibbles_properties_new ();
 
   setup_window ();
 
@@ -1097,7 +1080,9 @@ main (int argc, char **argv)
 
   gtk_main ();
 
-  gnome_accelerators_sync ();
+  gnibbles_properties_destroy (properties);
+
+  games_conf_shutdown ();
 
   g_object_unref (program);
 
