@@ -134,7 +134,7 @@ gnibbles_worm_set_start (GnibblesWorm * worm, guint t_xhead, guint t_yhead,
 gint
 gnibbles_worm_handle_keypress (GnibblesWorm * worm, guint keyval)
 {
-  gint key_left, key_right, key_up, key_down;
+  GnibblesWormProps *props;
 
 /*	if (worm->keypress) {
                 gnibbles_worm_queue_keypress (worm, keyval);
@@ -143,46 +143,33 @@ gnibbles_worm_handle_keypress (GnibblesWorm * worm, guint keyval)
 
 
 
-  if (ggz_network_mode) {
-    key_left = gdk_keyval_from_name (properties->wormprops[0]->left);
-    key_right = gdk_keyval_from_name (properties->wormprops[0]->right);
-    key_up = gdk_keyval_from_name (properties->wormprops[0]->up);
-    key_down = gdk_keyval_from_name (properties->wormprops[0]->down);
-  } else {
-    key_left =
-      gdk_keyval_from_name (properties->wormprops[worm->number]->left);
-    key_right =
-      gdk_keyval_from_name (properties->wormprops[worm->number]->right);
-    key_up = gdk_keyval_from_name (properties->wormprops[worm->number]->up);
-    key_down =
-      gdk_keyval_from_name (properties->wormprops[worm->number]->down);
-  }
+  props = properties->wormprops[ggz_network_mode ? 0 : worm->number];
 
   if (properties->wormprops[worm->number]->relmove) {
-    if (keyval == key_left)
+    if (keyval == props->left)
       worm_handle_direction (worm->number, worm->direction - 1);
-    else if (keyval == key_right)
+    else if (keyval == props->right)
       worm_handle_direction (worm->number, worm->direction + 1);
     else
       return FALSE;
     return TRUE;
   } else {
-    if ((keyval == key_up) && (worm->direction != WORMDOWN)) {
+    if ((keyval == props->up) && (worm->direction != WORMDOWN)) {
       worm_handle_direction (worm->number, WORMUP);
       /*worm->keypress = 1; */
       return TRUE;
     }
-    if ((keyval == key_right) && (worm->direction != WORMLEFT)) {
+    if ((keyval == props->right) && (worm->direction != WORMLEFT)) {
       worm_handle_direction (worm->number, WORMRIGHT);
       /*worm->keypress = 1; */
       return TRUE;
     }
-    if ((keyval == key_down) && (worm->direction != WORMUP)) {
+    if ((keyval == props->down) && (worm->direction != WORMUP)) {
       worm_handle_direction (worm->number, WORMDOWN);
       /*worm->keypress = 1; */
       return TRUE;
     }
-    if ((keyval == key_left) && (worm->direction != WORMRIGHT)) {
+    if ((keyval == props->left) && (worm->direction != WORMRIGHT)) {
       worm_handle_direction (worm->number, WORMLEFT);
       /*worm->keypress = 1; */
       return TRUE;
@@ -253,7 +240,7 @@ gnibbles_worm_grok_bonus (GnibblesWorm * worm)
 
   if (gnibbles_boni_fake (boni, worm->xhead, worm->yhead)) {
     g_timeout_add (1, (GtkFunction) gnibbles_worm_reverse, worm);
-    gnibbles_play_sound ("reverse");
+    games_sound_play ("reverse");
     return;
   }
 
@@ -262,30 +249,30 @@ gnibbles_worm_grok_bonus (GnibblesWorm * worm)
     boni->numleft--;
     worm->change += (NUMBONI - boni->numleft) * GROWFACTOR;
     worm->score += (NUMBONI - boni->numleft) * current_level;
-    gnibbles_play_sound ("gobble");
+    games_sound_play ("gobble");
     break;
   case BONUSDOUBLE:
     worm->score += (worm->length + worm->change) * current_level;
     worm->change += worm->length + worm->change;
-    gnibbles_play_sound ("bonus");
+    games_sound_play ("bonus");
     break;
   case BONUSHALF:
     if (worm->length + worm->change > 2) {
       worm->score += ((worm->length + worm->change) / 2) * current_level;
       worm->change -= (worm->length + worm->change) / 2;
-      gnibbles_play_sound ("bonus");
+      games_sound_play ("bonus");
     }
     break;
   case BONUSLIFE:
     worm->lives += 1;
-    gnibbles_play_sound ("life");
+    games_sound_play ("life");
     break;
   case BONUSREVERSE:
     for (i = 0; i < properties->numworms; i++)
       if (worm != worms[i])
 	g_timeout_add (1, (GSourceFunc)
 		       gnibbles_worm_reverse, worms[i]);
-    gnibbles_play_sound ("reverse");
+    games_sound_play ("reverse");
     break;
   }
 }
@@ -349,7 +336,7 @@ gnibbles_worm_draw_head (GnibblesWorm * worm)
 
   if (board[worm->xhead][worm->yhead] == WARPLETTER) {
     gnibbles_warpmanager_worm_change_pos (warpmanager, worm);
-    gnibbles_play_sound ("teleport");
+    games_sound_play ("teleport");
   }
 
   worm->start++;
