@@ -20,16 +20,25 @@
  */
 
 #include <config.h>
+
 #include <string.h>
 #include <math.h>
-#include <gdk-pixbuf/gdk-pixbuf.h>
-#include <games-clock.h>
 #include <time.h>
-#include <gconf/gconf-client.h>
-#include <gnome.h>
+#include <stdlib.h>
+
+#include <glib/gi18n.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gtk/gtk.h>
+
+#include <games-clock.h>
 #include <games-stock.h>
 #include <games-scores.h>
 #include <games-scores-dialog.h>
+#include <games-conf.h>
+
+#ifdef HAVE_GNOME
+#include <gnome.h>
+#endif /* HAVE_GNOME */
 
 #define APPNAME "gnotravex"
 #define APPNAME_LONG N_("Tetravex")
@@ -44,11 +53,12 @@
 #define UNUSED 1
 #define USED 0
 
-#define KEY_GRID_SIZE     "/apps/gnotravex/grid_size"
-#define KEY_WINDOW_WIDTH  "/apps/gnotravex/width"
-#define KEY_WINDOW_HEIGHT "/apps/gnotravex/height"
-#define KEY_CLICK_MOVE    "/apps/gnotravex/click_to_move"
-#define KEY_SHOW_COLOURS  "/apps/gnotravex/colours"
+#define KEY_GRID_SIZE     "grid_size"
+#define KEY_CLICK_MOVE    "click_to_move"
+#define KEY_SHOW_COLOURS  "colours"
+
+#define DEFAULT_WIDTH 320
+#define DEFAULT_HEIGHT 240
 
 /* i18n in-game numbers, replaceable with single-character local ideograms. */
 static const char *translatable_number[10] =
@@ -83,8 +93,6 @@ static int gap;
 
 static GdkPixmap *buffer = NULL;
 
-static GConfClient *gconf_client;
-
 typedef struct _mover {
   GdkWindow *window;
   GdkPixmap *pixmap;
@@ -249,8 +257,10 @@ void clickmove_toggle_cb (GtkToggleAction *, gpointer);
 void hint_move (gint, gint, gint, gint);
 gint show_score_dialog (gint, gboolean);
 void new_game (void);
+#ifdef HAVE_GNOME
 static gint save_state (GnomeClient *, gint, GnomeRestartStyle,
 			gint, GnomeInteractStyle, gint, gpointer);
+#endif                     
 static void set_fullscreen_actions (gboolean is_fullscreen);
 static void fullscreen_cb (GtkAction * action);
 static gboolean window_state_cb (GtkWidget * widget, GdkEventWindowState * event);
@@ -396,13 +406,18 @@ static const GOptionEntry options[] = {
 int
 main (int argc, char **argv)
 {
-  GnomeClient *client;
-  GnomeProgram *program;
   GOptionContext *context;
   GtkWidget *vbox;
   GtkWidget *menubar;
   GtkUIManager *ui_manager;
   GtkAccelGroup *accel_group;
+#ifdef HAVE_GNOME
+  GnomeClient *client;
+  GnomeProgram *program;
+#else
+  gboolean retval;
+  GError *error = NULL;
+#endif
 
 #if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
   /* If we're going to use gnome-vfs, we need to init threads before
@@ -419,36 +434,50 @@ main (int argc, char **argv)
 
   context = g_option_context_new (NULL);
   g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
+
+#ifdef HAVE_GNOME
   program = gnome_program_init (APPNAME, VERSION,
 				LIBGNOMEUI_MODULE,
 				argc, argv,
 				GNOME_PARAM_GOPTION_CONTEXT, context,
 				GNOME_PARAM_APP_DATADIR, DATADIR,
                                 NULL);
+  
+  client = gnome_master_client ();
+  g_signal_connect (client, "save_yourself",
+                    G_CALLBACK (save_state), argv[0]);
+  g_signal_connect (client, "die",
+                    G_CALLBACK (quit_game_cb), argv[0]);
+#else
+  g_option_context_add_group (context, gtk_get_option_group (TRUE));
+
+  retval = g_option_context_parse (context, &argc, &argv, &error);
+  g_option_context_free (context);
+  if (!retval) {
+    g_print ("%s", error->message);
+    g_error_free (error);
+    exit (1);
+  }
+#endif /* HAVE_GNOME */
+
+  g_set_application_name (_(APPNAME_LONG));
+
+  games_conf_initialise (APPNAME);
 
   highscores = games_scores_new (&scoredesc);
 
-  gtk_window_set_default_icon_name ("gnome-tetravex");
-  client = gnome_master_client ();
-  g_object_ref (G_OBJECT (client));
-
-  g_signal_connect (G_OBJECT (client), "save_yourself",
-		    G_CALLBACK (save_state), argv[0]);
-  g_signal_connect (G_OBJECT (client), "die",
-		    G_CALLBACK (quit_game_cb), argv[0]);
-
   games_stock_init ();
 
-  gconf_client = gconf_client_get_default ();
+  gtk_window_set_default_icon_name ("gnome-tetravex");
 
   if (size == -1)
-    size = gconf_client_get_int (gconf_client, KEY_GRID_SIZE, NULL);
+    size = games_conf_get_integer (NULL, KEY_GRID_SIZE, NULL);
   if (size < 2 || size > 6)
     size = 3;
   games_scores_set_category (highscores, scorecats[size - 2].key);
 
-  coloured_tiles = gconf_client_get_bool (gconf_client, KEY_SHOW_COLOURS, NULL);
-  click_to_move = gconf_client_get_bool (gconf_client, KEY_CLICK_MOVE, NULL);
+  coloured_tiles = games_conf_get_boolean (NULL, KEY_SHOW_COLOURS, NULL);
+  click_to_move = games_conf_get_boolean (NULL, KEY_CLICK_MOVE, NULL);
 
   load_pixmaps ();
   create_window ();
@@ -508,9 +537,11 @@ main (int argc, char **argv)
 
   gtk_main ();
 
-  gnome_accelerators_sync ();
+  games_conf_shutdown ();
 
+#ifdef HAVE_GNOME
   g_object_unref (program);
+#endif /* HAVE_GNOME */
 
   return 0;
 }
@@ -561,50 +592,18 @@ update_move_menu_sensitivity (void)
   gtk_action_set_sensitive (move_down_action, s);
 }
 
-static gint
-get_window_width (void)
-{
-  int width;
-  int screen_width;
-
-  width = gconf_client_get_int (gconf_client, KEY_WINDOW_WIDTH, NULL);
-  if (width < 320)
-    width = 320;
-  screen_width =
-    gdk_screen_get_width (gtk_window_get_screen (GTK_WINDOW (window)));
-  if (width > screen_width)
-    width = screen_width;
-
-  return width;
-}
-
-static gint
-get_window_height (void)
-{
-  int height;
-  int screen_height;
-
-  height = gconf_client_get_int (gconf_client, KEY_WINDOW_HEIGHT, NULL);
-  if (height < 240)
-    height = 240;
-  screen_height =
-    gdk_screen_get_height (gtk_window_get_screen (GTK_WINDOW (window)));
-  if (height > screen_height)
-    height = screen_height;
-
-  return height;
-}
 
 void
 create_window (void)
 {
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+
   gtk_window_set_title (GTK_WINDOW (window), _(APPNAME_LONG));
 
+  gtk_window_set_default_size (GTK_WINDOW (window), DEFAULT_WIDTH, DEFAULT_HEIGHT);
+  games_conf_add_window (GTK_WINDOW (window), NULL);
   gtk_window_set_resizable (GTK_WINDOW (window), TRUE);
-  gtk_widget_set_size_request (window, 320, 240);
-  gtk_window_set_default_size (GTK_WINDOW (window), get_window_width (),
-			       get_window_height ());
+
   gtk_widget_realize (window);
   g_signal_connect (G_OBJECT (window), "delete_event",
 		    G_CALLBACK (quit_game_cb), NULL);
@@ -1293,7 +1292,6 @@ void
 update_tile_size (gint screen_width, gint screen_height)
 {
   gint xt_size, yt_size;
-  gint window_width, window_height;
 
   /* We aim for the gap and the corners to be 1/2 a tile wide. */
   xt_size = (2 * screen_width) / (4 * size + 3);
@@ -1317,10 +1315,6 @@ update_tile_size (gint screen_width, gint screen_height)
 
   /* Rebuild the tile/socket vertices when required */
   rebuild_vertices = TRUE;
-
-  gtk_window_get_size (GTK_WINDOW (window), &window_width, &window_height);
-  gconf_client_set_int (gconf_client, KEY_WINDOW_WIDTH, window_width, NULL);
-  gconf_client_set_int (gconf_client, KEY_WINDOW_HEIGHT, window_height, NULL);
 }
 
 gboolean
@@ -1678,6 +1672,8 @@ quit_game_cb (void)
   gtk_main_quit ();
 }
 
+#ifdef HAVE_GNOME
+
 static gint
 save_state (GnomeClient * client, gint phase,
 	    GnomeRestartStyle save_style, gint shutdown,
@@ -1706,6 +1702,7 @@ save_state (GnomeClient * client, gint phase,
   return TRUE;
 }
 
+#endif /* HAVE_GNOME */
 
 void
 size_cb (GtkAction * action, gpointer data)
@@ -1725,7 +1722,7 @@ size_cb (GtkAction * action, gpointer data)
   size = newsize;
   update_tile_size (width, height);
   games_scores_set_category (highscores, scorecats[size - 2].key);
-  gconf_client_set_int (gconf_client, KEY_GRID_SIZE, size, NULL);
+  games_conf_set_integer (NULL, KEY_GRID_SIZE, size);
   gtk_action_activate (new_game_action);
 }
 
@@ -1733,8 +1730,7 @@ void
 show_colours_toggle_cb (GtkToggleAction * togglebutton, gpointer data)
 {
   coloured_tiles = gtk_toggle_action_get_active (togglebutton);
-  gconf_client_set_bool (gconf_client, KEY_SHOW_COLOURS, coloured_tiles,
-			 NULL);
+  games_conf_set_boolean (NULL, KEY_SHOW_COLOURS, coloured_tiles);
   redraw_all ();
 }
 
@@ -1742,8 +1738,7 @@ void
 clickmove_toggle_cb(GtkToggleAction * togglebutton, gpointer data)
 {
   click_to_move = gtk_toggle_action_get_active (togglebutton);
-   
-  gconf_client_set_bool (gconf_client, KEY_CLICK_MOVE, click_to_move, NULL);
+  games_conf_set_boolean (NULL, KEY_CLICK_MOVE, click_to_move);
 }
 
 void
@@ -1914,7 +1909,11 @@ solve_cb (GtkAction * action, gpointer data)
 void
 help_cb (GtkAction * action, gpointer data)
 {
+#ifdef HAVE_GNOME
   gnome_help_display ("gnotravex.xml", NULL, NULL);
+#else
+#warning need to port help to gtk-only!
+#endif /* HAVE_GNOME */
 }
 
 void
@@ -1927,7 +1926,11 @@ about_cb (GtkAction * action, gpointer data)
   gchar *license = games_get_license (_(APPNAME_LONG));
 
   gtk_show_about_dialog (GTK_WINDOW (window),
+#if GTK_CHECK_VERSION (2, 11, 0)
+                         "program-name", _(APPNAME_LONG),
+#else
 			 "name", _(APPNAME_LONG),
+#endif
 			 "version", VERSION,
 			 "comments",
 			 _("GNOME Tetravex is a simple puzzle where "
@@ -1935,12 +1938,15 @@ about_cb (GtkAction * action, gpointer data)
 			   "same numbers are touching each other."),
 			 "copyright",
 			 "Copyright \xc2\xa9 1999-2007 Lars Rydlinge",
-			 "license", license, "authors", authors,
-			 "documenters", documenters, "translator_credits",
-			 _("translator-credits"), "logo-icon-name",
-			 "gnome-tetravex", "website",
-			 "http://www.gnome.org/projects/gnome-games/",
-			 "wrap-license", TRUE, NULL);
+			 "license", license,
+                         "wrap-license", TRUE,
+                         "authors", authors,
+			 "documenters", documenters,
+                         "translator-credits", _("translator-credits"),
+                         "logo-icon-name", "gnome-tetravex",
+                         "website", "http://www.gnome.org/projects/gnome-games",
+                         "website-label", _("GNOME Games web site"),
+                         NULL);
   g_free (license);
 }
 
@@ -1980,23 +1986,23 @@ get_pixmap (const char *filename)
 {
   GdkPixmap *ret;
   GdkPixbuf *im;
-  char *fullname = gnome_program_locate_file (NULL,
-					      GNOME_FILE_DOMAIN_APP_PIXMAP,
-					      filename, TRUE, NULL);
+  char *path;
+  GError *error = NULL;
 
-  if (fullname == NULL)
-    return NULL;
-
-  im = gdk_pixbuf_new_from_file (fullname, NULL);
+  path = g_build_filename (PIXMAPDIR, filename, NULL);
+  im = gdk_pixbuf_new_from_file (path, &error);
   if (im != NULL) {
     gdk_pixbuf_render_pixmap_and_mask_for_colormap (im,
 						    gdk_colormap_get_system
 						    (), &ret, NULL, 127);
     gdk_pixbuf_unref (im);
   } else {
+    g_warning ("Error loading file '%s': %s\n", path, error->message);
+    g_error_free (error);
+
     ret = NULL;
   }
-  g_free (fullname);
+  g_free (path);
 
   return ret;
 }
@@ -2004,10 +2010,6 @@ get_pixmap (const char *filename)
 static void
 load_pixmaps (void)
 {
-  gchar *buffer;
-
-  buffer = g_build_filename (PIXMAPDIR, "gnotravex", "baize.png", NULL);
-  default_background_pixmap = get_pixmap (buffer);
-  g_free (buffer);
+  default_background_pixmap = get_pixmap ("baize.png");
 }
 
