@@ -29,6 +29,7 @@
 #include <string.h>
 #include <games-stock.h>
 #include <games-sound.h>
+#include <games-conf.h>
 
 #ifdef GGZ_CLIENT
 #include <games-dlg-chat.h>
@@ -41,6 +42,9 @@
 #include "othello.h"
 #include "properties.h"
 
+#define APP_NAME "iagno"
+#define APP_NAME_LONG N_("Iagno")
+
 GnomeAppBar *appbar;
 GtkWidget *window;
 GtkWidget *notebook;
@@ -266,36 +270,6 @@ undo_move_cb (GtkWidget * widget, gpointer data)
   check_computer_players ();
 }
 
-void
-black_level_cb (GtkWidget * widget, gpointer data)
-{
-  int tmp;
-
-  tmp = atoi ((gchar *) data);
-
-  gnome_config_set_int ("/iagno/Preferences/blacklevel", tmp);
-  gnome_config_sync ();
-
-  black_computer_level = tmp;
-
-  check_computer_players ();
-}
-
-void
-white_level_cb (GtkWidget * widget, gpointer data)
-{
-  int tmp;
-
-  tmp = atoi ((gchar *) data);
-
-  gnome_config_set_int ("/iagno/Preferences/whitelevel", tmp);
-  gnome_config_sync ();
-
-  white_computer_level = tmp;
-
-  check_computer_players ();
-}
-
 void
 about_cb (GtkWidget * widget, gpointer data)
 {
@@ -303,21 +277,22 @@ about_cb (GtkWidget * widget, gpointer data)
 
   const gchar *documenters[] = { "Eric Baudais", NULL };
 
-  gchar *license = games_get_license (_("Iagno"));
-
+  gchar *license = games_get_license (_(APP_NAME_LONG));
 
   gtk_show_about_dialog (GTK_WINDOW (window),
-			 "name", _("Iagno"),
+			 "name", _(APP_NAME_LONG),
 			 "version", VERSION,
 			 "copyright",
-			 "Copyright \xc2\xa9 1998-2007 Ian Peters", "license",
-			 license, "comments",
-			 _("A disk flipping game derived from Reversi."),
-			 "authors", authors, "documenters", documenters,
-			 "translator_credits", _("translator-credits"),
-			 "logo-icon-name", "gnome-iagno", "website",
-			 "http://www.gnome.org/projects/gnome-games/",
-			 "wrap-license", TRUE, NULL);
+			 "Copyright \xc2\xa9 1998-2007 Ian Peters",
+                         "license", license,
+                         "comments", _("A disk flipping game derived from Reversi."),
+			 "authors", authors,
+                         "documenters", documenters,
+			 "translator-credits", _("translator-credits"),
+			 "logo-icon-name", "gnome-iagno",
+                         "website", "http://www.gnome.org/projects/gnome-games/",
+			 "wrap-license", TRUE,
+                         NULL);
   g_free (license);
 }
 
@@ -642,7 +617,9 @@ create_window (void)
 {
   GtkWidget *table;
 
-  window = gnome_app_new ("iagno", _("Iagno"));
+  window = gnome_app_new ("iagno", _(APP_NAME_LONG));
+
+  games_conf_add_window (GTK_WINDOW (window), NULL);
 
   notebook = gtk_notebook_new ();
   gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
@@ -902,9 +879,9 @@ main (int argc, char **argv)
 
   g_thread_init (NULL);
 
-  context = g_option_context_new ("");
+  context = g_option_context_new (NULL);
   g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
-  g_option_context_add_group (context, games_sound_get_option_group ());
+  games_sound_add_option_group (context);
 
   program = gnome_program_init ("iagno", VERSION,
 				LIBGNOMEUI_MODULE,
@@ -914,9 +891,9 @@ main (int argc, char **argv)
 
   gtk_window_set_default_icon_name ("gnome-iagno");
 
-  client = gnome_master_client ();
+  games_conf_initialise (APP_NAME);
 
-  g_object_ref (G_OBJECT (client));
+  client = gnome_master_client ();
 
   g_signal_connect (G_OBJECT (client), "save_yourself",
 		    G_CALLBACK (save_state), argv[0]);
@@ -948,6 +925,8 @@ main (int argc, char **argv)
 
   gtk_main ();
 
+  games_conf_shutdown ();
+
   g_object_unref (program);
 
   return 0;
