@@ -14,18 +14,17 @@
 #ifndef MAHJONGG_H
 #define MAHJONGG_H
 
-#include <gnome.h>
+#include <glib.h>
 
 #include "maps.h"
 
-
 #define MAX_TILES_STR "144"
 
 extern tilepos *pos;
 
 typedef struct _tile tile;
 
-struct _tile{
+struct _tile {
   int type;
   int image;
   int visible;
@@ -36,11 +35,10 @@ struct _tile{
 
 void tile_event (gint tileno, gint button);
 
-void mahjongg_theme_warning (gchar *message_format);
+void mahjongg_theme_warning (gchar * message_format);
 
 extern tile tiles[MAX_TILES];
 extern gint paused;
-extern gchar * tileset;
+extern gchar *tileset;
 
 #endif /* MAHJONGG_H */
-
